==> opencascade-7.8.1-2.gpkg.tar: image/usr/lib64/cmake/opencascade/OpenCASCADEVisualizationTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "TKService" for configuration "RelWithDebInfo"
set_property(TARGET TKService APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKService PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKService.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKService.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKService )
list(APPEND _cmake_import_check_files_for_TKService "${_IMPORT_PREFIX}/lib64/opencascade/libTKService.so.7.8.1" )

# Import target "TKV3d" for configuration "RelWithDebInfo"
set_property(TARGET TKV3d APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKV3d PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKV3d.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKV3d.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKV3d )
list(APPEND _cmake_import_check_files_for_TKV3d "${_IMPORT_PREFIX}/lib64/opencascade/libTKV3d.so.7.8.1" )

# Import target "TKOpenGl" for configuration "RelWithDebInfo"
set_property(TARGET TKOpenGl APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKOpenGl PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKOpenGl.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKOpenGl.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKOpenGl )
list(APPEND _cmake_import_check_files_for_TKOpenGl "${_IMPORT_PREFIX}/lib64/opencascade/libTKOpenGl.so.7.8.1" )

# Import target "TKMeshVS" for configuration "RelWithDebInfo"
set_property(TARGET TKMeshVS APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKMeshVS PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKMeshVS.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKMeshVS.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKMeshVS )
list(APPEND _cmake_import_check_files_for_TKMeshVS "${_IMPORT_PREFIX}/lib64/opencascade/libTKMeshVS.so.7.8.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> opencascade-7.8.1-7.gpkg.tar: image/usr/lib64/cmake/opencascade/OpenCASCADEVisualizationTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "TKService" for configuration "RelWithDebInfo"
set_property(TARGET TKService APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKService PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKService.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKService.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKService )
list(APPEND _cmake_import_check_files_for_TKService "${_IMPORT_PREFIX}/lib64/opencascade/libTKService.so.7.8.1" )

# Import target "TKV3d" for configuration "RelWithDebInfo"
set_property(TARGET TKV3d APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKV3d PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKV3d.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKV3d.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKV3d )
list(APPEND _cmake_import_check_files_for_TKV3d "${_IMPORT_PREFIX}/lib64/opencascade/libTKV3d.so.7.8.1" )

# Import target "TKOpenGl" for configuration "RelWithDebInfo"
set_property(TARGET TKOpenGl APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKOpenGl PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKOpenGl.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKOpenGl.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKOpenGl )
list(APPEND _cmake_import_check_files_for_TKOpenGl "${_IMPORT_PREFIX}/lib64/opencascade/libTKOpenGl.so.7.8.1" )

# Import target "TKMeshVS" for configuration "RelWithDebInfo"
set_property(TARGET TKMeshVS APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKMeshVS PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKMeshVS.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKMeshVS.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKMeshVS )
list(APPEND _cmake_import_check_files_for_TKMeshVS "${_IMPORT_PREFIX}/lib64/opencascade/libTKMeshVS.so.7.8.1" )

# Import target "TKIVtk" for configuration "RelWithDebInfo"
set_property(TARGET TKIVtk APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(TKIVtk PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/opencascade/libTKIVtk.so.7.8.1"
  IMPORTED_SONAME_RELWITHDEBINFO "libTKIVtk.so.7.8"
  )

list(APPEND _cmake_import_check_targets TKIVtk )
list(APPEND _cmake_import_check_files_for_TKIVtk "${_IMPORT_PREFIX}/lib64/opencascade/libTKIVtk.so.7.8.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
